/***********************************************************************************
*
* Copyright © 2017-2019 STMicroelectronics - All Rights Reserved
*
* License terms: STMicroelectronics Proprietary in accordance with licensing
* terms SLA0089 at www.st.com
*
* THIS SOFTWARE IS DISTRIBUTED "AS IS," AND ALL WARRANTIES ARE DISCLAIMED,
* INCLUDING MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*
* EVALUATION ONLY – NOT FOR USE IN PRODUCTION
************************************************************************************/

/* Extended registers for DP83848 */

#ifndef __DP83848_H__
#define __DP83848_H__

#include <phydev_if.h>

uint32_t dp83848_phydev_init(phydev_ops_t * ops);

/* name PHY Status Register */
#define DP83848_PHYSTS                                0x10
#define DP83848_PHYSTS_LINK_STATUS                    (1<<0)
#define DP83848_PHYSTS_SPEED_STATUS                   (1<<1)
#define DP83848_PHYSTS_DUPLEX_STATUS                  (1<<2)
#define DP83848_PHYSTS_LOOPBACK_STATUS                (1<<3)
#define DP83848_PHYSTS_AUTO_NEG_COMPLETE              (1<<4)
#define DP83848_PHYSTS_JABBER_DETECT                  (1<<5)
#define DP83848_PHYSTS_RF                             (1<<6)
#define DP83848_PHYSTS_DP83848_INTERRUPT              (1<<7)
#define DP83848_PHYSTS_PAGE_RECEIVED                  (1<<8)
#define DP83848_PHYSTS_DESCRAMBLER_LOCK               (1<<9)
#define DP83848_PHYSTS_SIGNAL_DETECT                  (1<<10)
#define DP83848_PHYSTS_FALSE_CARRIER_SENSE_LATCH      (1<<11)
#define DP83848_PHYSTS_POLARITY_STATUS                (1<<12)
#define DP83848_PHYSTS_RECEIVE_ERROR_LATCH            (1<<13)
#define DP83848_PHYSTS_MDIX_MODE                      (1<<14)

/* name Interrupt Ctrl Register. */
#define DP83848_MICR                                  0x11
#define DP83848_MICR_INT_OE                           (1<<0)
#define DP83848_MICR_INT_EN                           (1<<1)
#define DP83848_MICR_INT_TEST                         (1<<2)

/* name Interrupt Status Register. */
#define DP83848_MISR                                  0x12
#define DP83848_MISR_RHF_INT_EN                       (1<<0)
#define DP83848_MISR_FHF_INT_EN                       (1<<1)
#define DP83848_MISR_ANC_INT_EN                       (1<<2)
#define DP83848_MISR_DUP_INT_EN                       (1<<3)
#define DP83848_MISR_SPD_INT_EN                       (1<<4)
#define DP83848_MISR_LINK_INT_EN                      (1<<5)
#define DP83848_MISR_ED_INT_EN                        (1<<6)
#define DP83848_MISR_RHF_INT                          (1<<8)
#define DP83848_MISR_FHF_INT                          (1<<9)
#define DP83848_MISR_ANC_INT                          (1<<10)
#define DP83848_MISR_DUP_INT                          (1<<11)
#define DP83848_MISR_SPD_INT                          (1<<12)
#define DP83848_MISR_LINK_INT                         (1<<13)
#define DP83848_MISR_ED_INT                           (1<<14)

/* name False Carrier Sense Counter Register. */
#define DP83848_FCSCR                                 0x14
#define DP83848_FCSCR_FCSCNT                          0x00FF

/* name Receiver Error Counter Register. */
#define DP83848_RECR                                  0x15
#define DP83848_RECR_RXERCNT                          0x00FF

/* name 100 Mb/s PCS Configuration and Status Register */
#define DP83848_PCSR                                  0x16
#define DP83848_PCSR_NRZI_BYPASS                      (1<<2)
#define DP83848_PCSR_FORCE_100_OK                     (1<<5)
#define DP83848_PCSR_DESC_TIME                        (1<<7)
#define DP83848_PCSR_SD_OPTION                        (1<<8)
#define DP83848_PCSR_SD FORCE PMA                     (1<<9)
#define DP83848_PCSR_TQ_EN                            (1<<10)
#define DP83848_PCSR_FREE_CLK                         (1<<11)

/* name RMII and Bypass Register */
#define DP83848_RBR                                   0x17
#define DP83848_RBR_ELAST_BUF                         0x0003
#define DP83848_RBR_RX_UNF_STS                        (1<<2)
#define DP83848_RBR_RX_OVF_STS                        (1<<3)
#define DP83848_RBR_RMII_REV1_0                       (1<<4)
#define DP83848_RBR_RMII_MODE                         (1<<5)

/* name LED Direct Control Register */
#define DP83848_LEDCR                                 0x18
#define DP83848_LEDCR_DRV_SPDLED                      (1<<0)
#define DP83848_LEDCR_DRV_LNKLED                      (1<<1)
#define DP83848_LEDCR_DRV_ACTLED                      (1<<2)
#define DP83848_LEDCR_SPDLED                          (1<<3)
#define DP83848_LEDCR_LNKLED                          (1<<4)
#define DP83848_LEDCR_ACTLED                          (1<<5)

/* name PHY Control Register */
#define DP83848_PHYCR                                 0x19
#define DP83848_PHYCR_PHYADDR                         0x001F
#define DP83848_PHYCR_LED_CNFG                        0x0060
#define DP83848_PHYCR_BP_STRETCH                      (1<<7)
#define DP83848_PHYCR_BIST_START                      (1<<8)
#define DP83848_PHYCR_BIST_STATUS                     (1<<9)
#define DP83848_PHYCR_PSR_15                          (1<<10)
#define DP83848_PHYCR_BIST_FE                         (1<<11)
#define DP83848_PHYCR_PAUSE_TX                        (1<<12)
#define DP83848_PHYCR_PAUSE_RX                        (1<<13)
#define DP83848_PHYCR_FORCE_MDIX                      (1<<14)
#define DP83848_PHYCR_MDIX_EN                         (1<<15)

/* name 10Base-T Status/Control Register */
#define DP83848_10BTSCR                               0x1A
#define DP83848_10BTSCR_JABBER_DIS                    (1<<0)
#define DP83848_10BTSCR_HEARTBEAT_DIS                 (1<<1)
#define DP83848_10BTSCR_POLARITY                      (1<<4)
#define DP83848_10BTSCR_FORCE_LINK_10                 (1<<6)
#define DP83848_10BTSCR_LP_DIS                        (1<<7)
#define DP83848_10BTSCR_LOOPBACK_10_DIS               (1<<8)
#define DP83848_10BTSCR_SQUELCH                       0x0E00
#define DP83848_10BTSCR_10BT_SERIAL                   (1<<15)

/* name CD Test and BIST Extensions Register */
#define DP83848_CDCTRL1                               0x1B
#define DP83848_CDCTRL1_CDPATTSEL                     0x0003
#define DP83848_CDCTRL1_10MEG_PATT_GAP                (1<<2)
#define DP83848_CDCTRL1_CDPATTEN_10                   (1<<4)
#define DP83848_CDCTRL1_BIST_CONT_MODE                (1<<5)
#define DP83848_CDCTRL1_BIST_ERROR_COUNT              0xFF00

/* name Energy Detect Control */
#define DP83848_EDCR                                  0x1D
#define DP83848_EDCR_ED_DATA_COUNT                    0x000F
#define DP83848_EDCR_ED_ERR_COUNT                     0x00F0
#define DP83848_EDCR_ED_DATA_MET                      (1<<8)
#define DP83848_EDCR_ED_ERR_MET                       (1<<9)
#define DP83848_EDCR_ED_PWR_STATE                     (1<<10)
#define DP83848_EDCR_ED_BURST_DIS                     (1<<11)
#define DP83848_EDCR_ED_MAN                           (1<<12)
#define DP83848_EDCR_ED_AUTO_DOWN                     (1<<13)
#define DP83848_EDCR_ED_AUTO_UP                       (1<<14)
#define DP83848_EDCR_ED_EN                            (1<<15)

#endif				/* __DP83848_H__ */
